@@ -1,7 +1,10 @@
-from typing import List, Callable
+from collections import defaultdict
 from functools import partial
+from typing import Callable, List
+
 from gensim.models.keyedvectors import KeyedVectors
 
+
 def tokenize_with_ws(text: str, tokenizer: Callable[[str], List[str]]) -> List[str]:
     "Tokenize a string with whitespaces with the specified tokenizer"
     if isinstance(text, str):
@@ -16,10 +19,13 @@ def tokenizer_with_ws(
     "Returns a function which tokenizes a string with whitespaces based on the specified tokenizer"
     return partial(tokenize_with_ws, tokenizer=tokenizer)
 
+
 def generate_word2vec_format(index_to_key, vectors):
-    
-    key_vecs = "\n".join([w + ' ' + ' '.join(v) for w,v in  zip(index_to_key, vectors.astype(str))])
-    
+
+    key_vecs = "\n".join(
+        [w + " " + " ".join(v) for w, v in zip(index_to_key, vectors.astype(str))]
+    )
+
     return f"""{vectors.shape[0]} {vectors.shape[1]}
 {key_vecs}"""
 
@@ -29,6 +35,24 @@ class WordVector(KeyedVectors):
         self.vectors = vectors
         self.vector_size = vectors.shape[1]
         self.index_to_key = index_to_key
-        self.key_to_index = {word:n for n,word in enumerate(index_to_key)}
+        self.key_to_index = {word: n for n, word in enumerate(index_to_key)}
         self.norms = None
-        pass
\ No newline at end of file
+        pass
+
+
+def create_topic_dict(dictionary: dict[str, list]):
+    """
+    Function take a dictionary with topics as keys and keywords as values
+    and makes into appropriate dict. format for w2widget.
+    """
+
+    topic_dict = defaultdict(dict)
+
+    for key in dictionary.keys():
+        topic_words = dictionary[key]
+        topic_dict[key]["topic_words"] = topic_words
+        topic_dict[key]["search_words"] = topic_words
+        topic_dict[key]["negative_words"] = []
+        topic_dict[key]["skip_words"] = []
+
+    return dict(topic_dict)
